@@ -9,9 +9,28 @@
 
 #include "config.h"
 
+#define SNAPD_BUY_SUPPORT
+
 #include "snapd-snap.h"
 #include "snapd-enum-types.h"
 
+/**
+ * SECTION:snapd-snap
+ * @short_description: Snap metadata
+ * @include: snapd-glib/snapd-glib.h
+ *
+ * A #SnapdSnap contains the metadata for a given snap. Snap metadata can be
+ * retrieved using snapd_client_list_sync(), snapd_client_list_one_sync() or
+ * snapd_client_find_sync().
+ */
+
+/**
+ * SnapdSnap:
+ *
+ * #SnapdSnap is an opaque data structure and can only be accessed
+ * using the provided functions.
+ */
+
 struct _SnapdSnap
 {
     GObject parent_instance;
@@ -69,6 +88,8 @@ G_DEFINE_TYPE (SnapdSnap, snapd_snap, G_TYPE_OBJECT)
  * snapd_snap_get_apps:
  * @snap: a #SnapdSnap.
  *
+ * Get the apps this snap provides.
+ *
  * Returns: (transfer none) (element-type SnapdApp): an array of #SnapdApp.
  */
 GPtrArray *
@@ -82,7 +103,9 @@ snapd_snap_get_apps (SnapdSnap *snap)
  * snapd_snap_get_channel:
  * @snap: a #SnapdSnap.
  *
- * Returns: the channel this snap is from, e.g. "stable".
+ * Get the channel this snap is from, e.g. "stable".
+ *
+ * Returns: a channel name.
  */
 const gchar *
 snapd_snap_get_channel (SnapdSnap *snap)
@@ -95,7 +118,9 @@ snapd_snap_get_channel (SnapdSnap *snap)
  * snapd_snap_get_confinement:
  * @snap: a #SnapdSnap.
  *
- * Returns: the confinement this snap is using, e.g. %SNAPD_CONFINEMENT_STRICT.
+ * Get the confinement this snap is using, e.g. %SNAPD_CONFINEMENT_STRICT.
+ *
+ * Returns: a #SnapdConfinement.
  */
 SnapdConfinement
 snapd_snap_get_confinement (SnapdSnap *snap)
@@ -108,7 +133,9 @@ snapd_snap_get_confinement (SnapdSnap *snap)
  * snapd_snap_get_description:
  * @snap: a #SnapdSnap.
  *
- * Returns: a multi-line description of this snap.
+ * Get a multi-line description of this snap.
+ *
+ * Returns: description text.
  */
 const gchar *
 snapd_snap_get_description (SnapdSnap *snap)
@@ -121,7 +148,9 @@ snapd_snap_get_description (SnapdSnap *snap)
  * snapd_snap_get_developer:
  * @snap: a #SnapdSnap.
  *
- * Returns: the developer who created this snap.
+ * Get the developer who created this snap.
+ *
+ * Returns: a developer name.
  */
 const gchar *
 snapd_snap_get_developer (SnapdSnap *snap)
@@ -134,6 +163,8 @@ snapd_snap_get_developer (SnapdSnap *snap)
  * snapd_snap_get_devmode:
  * @snap: a #SnapdSnap.
  *
+ * Get if this snap is running in developmer mode.
+ *
  * Returns: %TRUE if this snap is running in devmode.
  */
 gboolean
@@ -147,7 +178,9 @@ snapd_snap_get_devmode (SnapdSnap *snap)
  * snapd_snap_get_download_size:
  * @snap: a #SnapdSnap.
  *
- * Returns: the download size of this snap in bytes or 0 if unknown.
+ * Get the download size of this snap or 0 if unknown.
+ *
+ * Returns: a byte count.
  */
 gint64
 snapd_snap_get_download_size (SnapdSnap *snap)
@@ -160,7 +193,10 @@ snapd_snap_get_download_size (SnapdSnap *snap)
  * snapd_snap_get_icon:
  * @snap: a #SnapdSnap.
  *
- * Returns: a URL for this icon or an absolte path to retrieve it from snapd.
+ * Get the icon for this Snap, either a URL or an absolute path to retrieve it
+ * from snapd directly.
+ *
+ * Returns: a URL or path.
  */
 const gchar *
 snapd_snap_get_icon (SnapdSnap *snap)
@@ -173,7 +209,9 @@ snapd_snap_get_icon (SnapdSnap *snap)
  * snapd_snap_get_id:
  * @snap: a #SnapdSnap.
  *
- * Returns: a unique ID for this snap.
+ * Gets the unique ID for this snap.
+ *
+ * Returns: an ID.
  */
 const gchar *
 snapd_snap_get_id (SnapdSnap *snap)
@@ -185,8 +223,10 @@ snapd_snap_get_id (SnapdSnap *snap)
 /**
  * snapd_snap_get_install_date:
  * @snap: a #SnapdSnap.
+ * 
+ * Get the date this snap was installed or %NULL if unknown.
  *
- * Returns: the date this snap was installed or %NULL if unknown.
+ * Returns: (allow-none): a #GDateTime or %NULL.
  */
 GDateTime *
 snapd_snap_get_install_date (SnapdSnap *snap)
@@ -199,7 +239,9 @@ snapd_snap_get_install_date (SnapdSnap *snap)
  * snapd_snap_get_installed_size:
  * @snap: a #SnapdSnap.
  *
- * Returns: the installed size of this snap in bytes or 0 if unknown / not installed.
+ * Get the installed size of this snap or 0 if unknown.
+ *
+ * Returns: a byte count.
  */
 gint64
 snapd_snap_get_installed_size (SnapdSnap *snap)
@@ -212,7 +254,10 @@ snapd_snap_get_installed_size (SnapdSnap *snap)
  * snapd_snap_get_name:
  * @snap: a #SnapdSnap.
  *
- * Returns: the name of this snap.
+ * Get the name of this snap. This is used to reference this snap, e.g. for
+ * installing / removing.
+ *
+ * Returns: a name.
  */
 const gchar *
 snapd_snap_get_name (SnapdSnap *snap)
@@ -225,7 +270,9 @@ snapd_snap_get_name (SnapdSnap *snap)
  * snapd_snap_get_prices:
  * @snap: a #SnapdSnap.
  *
- * Returns: (transfer none) (element-type SnapdPrice): prices that this snap can be purchased at.
+ * Get the prices that this snap can be purchased at.
+ *
+ * Returns: (transfer none) (element-type SnapdPrice): an array of prices.
  */
 GPtrArray *
 snapd_snap_get_prices (SnapdSnap *snap)
@@ -238,7 +285,9 @@ snapd_snap_get_prices (SnapdSnap *snap)
  * snapd_snap_get_private:
  * @snap: a #SnapdSnap.
  *
- * Returns: %TRUE if this is a private snap (only available to the developer).
+ * Get if this snap is only available to the developer.
+ *
+ * Returns: %TRUE if this is a private snap.
  */
 gboolean
 snapd_snap_get_private (SnapdSnap *snap)
@@ -251,7 +300,10 @@ snapd_snap_get_private (SnapdSnap *snap)
  * snapd_snap_get_revision:
  * @snap: a #SnapdSnap.
  *
- * Returns: the revision of this snap.
+ * Get the revision for this snap. The format of the string is undefined.
+ * See also snapd_snap_get_version().
+ *
+ * Returns: a revision string.
  */
 const gchar *
 snapd_snap_get_revision (SnapdSnap *snap)
@@ -264,7 +316,9 @@ snapd_snap_get_revision (SnapdSnap *snap)
  * snapd_snap_get_snap_type:
  * @snap: a #SnapdSnap.
  *
- * Returns: the type of snap, e.g. %SNAPD_SNAP_TYPE_APP
+ * Get the type of snap, e.g. %SNAPD_SNAP_TYPE_APP
+ *
+ * Returns: a #SnapdSnapType.
  */
 SnapdSnapType
 snapd_snap_get_snap_type (SnapdSnap *snap)
@@ -277,7 +331,9 @@ snapd_snap_get_snap_type (SnapdSnap *snap)
  * snapd_snap_get_status:
  * @snap: a #SnapdSnap.
  *
- * Returns: the current status of this snap, e.g. SNAPD_SNAP_STATUS_INSTALLED
+ * Get the current status of this snap, e.g. SNAPD_SNAP_STATUS_INSTALLED.
+ *
+ * Returns: a #SnapdSnapStatus.
  */
 SnapdSnapStatus
 snapd_snap_get_status (SnapdSnap *snap)
@@ -289,8 +345,10 @@ snapd_snap_get_status (SnapdSnap *snap)
 /**
  * snapd_snap_get_summary:
  * @snap: a #SnapdSnap.
+ * 
+ * Get a single line summary for this snap, e.g. "Best app ever!".
  *
- * Returns: a single line summary for this snap, e.g. "Best app ever!"
+ * Returns: a summary string.
  */
 const gchar *
 snapd_snap_get_summary (SnapdSnap *snap)
@@ -303,7 +361,10 @@ snapd_snap_get_summary (SnapdSnap *snap)
  * snapd_snap_get_trymode:
  * @snap: a #SnapdSnap.
  *
- * Returns: %TRUE if this snap is running in trymode.
+ * Get if this snap is running in try mode (installed locally and able to be
+ * directly modified).
+ *
+ * Returns: %TRUE if using trymode.
  */
 gboolean
 snapd_snap_get_trymode (SnapdSnap *snap)
@@ -316,7 +377,10 @@ snapd_snap_get_trymode (SnapdSnap *snap)
  * snapd_snap_get_version:
  * @snap: a #SnapdSnap.
  *
- * Returns: the version of this snap.
+ * Get the version for this snap. The format of the string is undefined.
+ * See also snapd_snap_get_revision().
+ *
+ * Returns: a version string.
  */
 const gchar *
 snapd_snap_get_version (SnapdSnap *snap)
